* Generic session options - set page and line size, no page breaks;
OPTIONS nonumber nodate nocenter pagesize=MAX linesize=120 formdlim='-';											
* Kill default titles on output; 
TITLE;

* Location for files to be saved - CHANGE THIS TO YOUR DIRECTORY;
%LET example=F:\Example Data\Chapter 3 Data\Two-Occasion;
LIBNAME example "&example.";

* Open SAS stacked version of ANOVA data into work (temporary) library;
* Centering predictors for analysis;
DATA work.prepost_stacked; SET example.Example3a; 
	time1 = time - 1;  * Time was coded 1,2;
	treat = group - 1; * Group was coded 1,2;
	LABEL time1 = "Time (0=pre-test, 1= post-test)"
		  treat = "Treatment Group (0=control, 1=treatment)";
RUN;

TITLE "Cell means by group and time for y outcome";
PROC MEANS MEAN STDERR MIN MAX DATA=work.prepost_stacked; CLASS group time; VAR y; RUN; TITLE;
TITLE "Marginal means by group for y outcome";
PROC MEANS MEAN STDERR MIN MAX DATA=work.prepost_stacked; CLASS group; VAR y; RUN; TITLE;
TITLE "Marginal means by time for y outcome";
PROC MEANS MEAN STDERR MIN MAX DATA=work.prepost_stacked; CLASS time; VAR y; RUN; TITLE;
TITLE "Grand mean for y outcome";
PROC MEANS MEAN STDERR MIN MAX DATA=work.prepost_stacked; VAR y; RUN; TITLE;

TITLE "Eq 3.1: Empty Between-Person model via MIXED";
PROC MIXED DATA=work.prepost_stacked NOITPRINT NOCLPRINT IC COVTEST METHOD=REML;
	CLASS PersonID time;
	MODEL y = / SOLUTION DDFM=BW;
	REPEATED time / R RCORR TYPE=VC SUBJECT=PersonID; 
RUN; TITLE;

TITLE "Eq 3.2: Empty Within-Person model via MIXED";
PROC MIXED DATA=work.prepost_stacked NOITPRINT NOCLPRINT IC COVTEST METHOD=REML;
	CLASS PersonID time;
	MODEL y =  / SOLUTION DDFM=BW;
	REPEATED time / R RCORR TYPE=CS SUBJECT=PersonID;
RUN; TITLE;

TITLE1 "Eq 3.7 (top): Between-Person Conditional (Predictor) Model via MIXED";
TITLE2 "Not using CLASS statement, manually dummy coding group and time"; 
PROC MIXED DATA=work.prepost_stacked NOITPRINT NOCLPRINT IC COVTEST METHOD=REML;
	CLASS PersonID time;
	MODEL y = time1 treat time1*treat / SOLUTION DDFM=BW;
	REPEATED time / R RCORR TYPE=VC SUBJECT=PersonID; 
	ESTIMATE "Mean: Control Group at Pre-Test"		intercept 1 time1 0 treat 0 time1*treat 0;
	ESTIMATE "Mean: Control Group at Post-Test"		intercept 1 time1 1 treat 0 time1*treat 0;
	ESTIMATE "Mean: Treatment Group at Pre-Test"	intercept 1 time1 0 treat 1 time1*treat 0;
	ESTIMATE "Mean: Treatment Group at Post-Test"	intercept 1 time1 1 treat 1 time1*treat 1;
	ESTIMATE "Time Effect for Control Group" 		time1 1 time1*treat 0;
	ESTIMATE "Time Effect for Treatment Group" 		time1 1 time1*treat 1;
	ESTIMATE "Group Effect at Pre-Test" 			treat 1 time1*treat 0;
	ESTIMATE "Group Effect at Post-Test" 			treat 1 time1*treat 1;
RUN; TITLE1; TITLE2;

TITLE1 "Eq 3.7 (bottom): Within-Person Conditional (Predictor) Model via MIXED";
TITLE2 "Not using CLASS statement, manually dummy coding group and time";
PROC MIXED DATA=work.prepost_stacked NOITPRINT NOCLPRINT iC COVTEST METHOD=REML;
	CLASS PersonID time;
	MODEL y = time1 treat time1*treat / SOLUTION DDFM=BW;
	REPEATED time / R RCORR TYPE=CS SUBJECT=PersonID;
	ESTIMATE "Mean: Control Group at Pre-Test"		intercept 1 time1 0 treat 0 time1*treat 0;
	ESTIMATE "Mean: Control Group at Post-Test"		intercept 1 time1 1 treat 0 time1*treat 0;
	ESTIMATE "Mean: Treatment Group at Pre-Test"	intercept 1 time1 0 treat 1 time1*treat 0;
	ESTIMATE "Mean: Treatment Group at Post-Test"	intercept 1 time1 1 treat 1 time1*treat 1;
	ESTIMATE "Time Effect for Control Group" 	time1 1 time1*treat 0;
	ESTIMATE "Time Effect for Treatment Group" 	time1 1 time1*treat 1;
	ESTIMATE "Group Effect at Pre-Test" 		treat 1 time1*treat 0;
	ESTIMATE "Group Effect at Post-Test" 		treat 1 time1*treat 1;
RUN; TITLE1; TITLE2;

TITLE1 "Eq 3.7 (bottom): Within-Person Conditional (Predictor) Model via MIXED";
TITLE2 "NOW using CLASS statement"; 
PROC MIXED DATA=work.prepost_stacked NOITPRINT NOCLPRINT IC COVTEST METHOD=REML;
	CLASS PersonID time time1 treat;
	MODEL y = time1 treat time1*treat / SOLUTION DDFM=BW;
	REPEATED time / R RCORR TYPE=CS SUBJECT=PersonID;
	LSMEANS time1 treat time1*treat / DIFF=ALL;
RUN; TITLE1; TITLE2;
